var searchData=
[
  ['g',['g',['../structplplot_1_1__N9.html#ac6f4b924e5b670191775937095230225',1,'plplot::_N9::g()'],['../structPLColor.html#ab71f4093766e02ce796389832582517a',1,'PLColor::g()']]],
  ['g_5fweinitializedwx',['g_weInitializedWx',['../wxwidgets_8cpp.html#a7124994185e3dab65cde4f58ec99f7a1',1,'wxwidgets.cpp']]],
  ['gc',['gc',['../structTkwDev.html#a8166e22ee1368fcea258b52224ef1878',1,'TkwDev::gc()'],['../structXwDev.html#a5476a3dc986ba91f5491f7e9f63e3ae1',1,'XwDev::gc()']]],
  ['gcxor',['gcXor',['../structTkwDisplay.html#a31baa71129de5785caaa7f5dbd2fc2bb',1,'TkwDisplay::gcXor()'],['../structXwDisplay.html#ad215e4872240e5a3464a7591aa608ac1',1,'XwDisplay::gcXor()']]],
  ['geometry',['geometry',['../structPLStream.html#a7844488c645193fee1f5e1f31df9798e',1,'PLStream::geometry()'],['../tkMain_8c.html#a3512ed15de220f178dc26334564c6463',1,'geometry():&#160;tkMain.c']]],
  ['get',['get',['../structtclMatrix.html#a1f07da9a87e675b7349e09253dcafbce',1,'tclMatrix::get()'],['../structplf2ops__t.html#a3d2ca85ae97972e8b4d6e0221aaedc27',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
  ['get_5fattr',['get_attr',['../structswig__globalvar.html#ab617d0ca02f7660a9e5fd31dceaf6475',1,'swig_globalvar']]],
  ['get_5fmethod',['get_method',['../structswig__octave__member.html#afc6d3dc3d5c938d5a29f53fb7237ea5a',1,'swig_octave_member']]],
  ['get_5fstring_5flength',['get_string_length',['../structPLStream.html#a97ec49d30120b332e4f9246019bc9800',1,'PLStream']]],
  ['getmethod',['getmethod',['../structswig__lua__attribute.html#ab18a92c81433b7b3de23856cda4b89b5',1,'swig_lua_attribute']]],
  ['gin',['gin',['../structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1',1,'TkDev::gin()'],['../structTkwDev.html#af1b4162860b1d4ba0850ae4ee3a5b583',1,'TkwDev::gin()'],['../structXwDev.html#ad563957b570e07fb4ff157e1082ad7f6',1,'XwDev::gin()']]],
  ['gradient_5findex',['gradient_index',['../structSVG.html#a1478ed065a8ac15a5ac5c7f3c03ce991',1,'SVG']]],
  ['graphics_5fanti_5faliasing',['graphics_anti_aliasing',['../structPLCairo.html#aaea63861125bfc78fd2d8e2f00d5fab4',1,'PLCairo::graphics_anti_aliasing()'],['../cairo_8c.html#a34b1934fb70098cfce56e45d2a44ea0e',1,'graphics_anti_aliasing():&#160;cairo.c']]],
  ['graphicsin',['graphicsIn',['../structMemoryMapHeader.html#ae4905de4351f1c48da7b902a5cca0920',1,'MemoryMapHeader']]],
  ['graphx',['graphx',['../structPLStream.html#ac97c1d9507b3b316c557f166eca17430',1,'PLStream']]],
  ['green',['green',['../structcdImageStruct.html#afdfee0cfe98ddb62dd049d97c6285695',1,'cdImageStruct']]],
  ['grid_5fcsa',['GRID_CSA',['../namespaceplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../namespaceplplotc.html#a00dc056fe56ebe194647cbd1162e343c',1,'plplotc.GRID_CSA()']]],
  ['grid_5fdtli',['GRID_DTLI',['../namespaceplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../namespaceplplotc.html#ac14adf4dbaa8066db6c3ba43dcb3e2f8',1,'plplotc.GRID_DTLI()']]],
  ['grid_5fnnaidw',['GRID_NNAIDW',['../namespaceplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../namespaceplplotc.html#ac3170cbecddcf4693801fffa3d313993',1,'plplotc.GRID_NNAIDW()']]],
  ['grid_5fnni',['GRID_NNI',['../namespaceplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../namespaceplplotc.html#a8ce11df5f81041361d9a7da90c273424',1,'plplotc.GRID_NNI()']]],
  ['grid_5fnnidw',['GRID_NNIDW',['../namespaceplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../namespaceplplotc.html#ad49fbf71d1599309e9d51e5f7abb0f85',1,'plplotc.GRID_NNIDW()']]],
  ['grid_5fnnli',['GRID_NNLI',['../namespaceplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../namespaceplplotc.html#ac3ae103afcb084bddb043b6ab48b552b',1,'plplotc.GRID_NNLI()']]]
];
